@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.15 2006/09/19 20:48:15 murrayc Exp $ */
+/* $Id: ustring.h,v 1.7 2004/06/04 02:25:40 daniel Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -232,13 +232,7 @@ public:
 
 #endif /* GLIBMM_HAVE_SUN_REVERSE_ITERATOR */
 
-#ifdef GLIBMM_HAVE_ALLOWS_STATIC_INLINE_NPOS
-  static GLIBMM_API const size_type npos = std::string::npos;
-#else
-  //The IRIX MipsPro compiler says "The indicated constant value is not known",
-  //so we need to initalize the static member data elsewhere.
-  static GLIBMM_API const size_type npos;
-#endif
+  static const size_type npos = std::string::npos;
 
   /*! Default constructor, which creates an empty string.
    */
@@ -269,13 +263,13 @@ public:
   /*! Construct a ustring as a copy of a substring.
    * @param src %Source ustring.
    * @param i Index of first character to copy from.
-   * @param n Number of UTF-8 characters to copy (defaults to copying the remainder).
+   * @param n Number of characters to copy (defaults to copying the remainder).
    */
   ustring(const ustring& src, size_type i, size_type n=npos);
 
   /*! Construct a ustring as a partial copy of a C string.
    * @param src %Source C string encoded as UTF-8.
-   * @param n Number of UTF-8 characters to copy.
+   * @param n Number of characters to copy.
    */
   ustring(const char* src, size_type n);
 
@@ -487,29 +481,9 @@ public:
 //! @name Retrieve the string's size.
 //! @{
 
-  /** Returns true if the string is empty. Equivalent to *this == "".
-   * @result Whether the string is empty.
-   */
-  bool empty()  const;
-
-  /** Returns the number of characters in the string, not including any null-termination.
-   * @result The number of UTF-8 characters.
-   *
-   * @see bytes(), empty() 
-   */
+  bool      empty()  const;
   size_type size()   const;
-
-  //We have length() as well as size(), because std::string has both.
-
-  /** This is the same as size().
-   */
   size_type length() const;
-  
-  /** Returns the number of bytes in the string, not including any null-termination.
-   * @result The number of bytes.
-   *
-   * @see size(), empty()
-   */
   size_type bytes()  const;
 
 //! @}
@@ -570,7 +544,7 @@ public:
 //! @{
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their uppercase equivalent, while honoring the current locale.  The
+   * their lowercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.  For instance, the German sharp&nbsp;s
    * <tt>&quot;&szlig;&quot;</tt> will be replaced by two characters
@@ -604,23 +578,7 @@ private:
   template <class In, class ValueType = typename Glib::IteratorTraits<In>::value_type>
 #endif
   struct SequenceToString;
-  
-  //The Tru64 compiler needs these partial specializations to be declared here,
-  //as well as defined later. That's probably correct. murrayc.
-  template <class In>
-  struct SequenceToString<In, char>;
 
-  template <class In>
-  struct SequenceToString<In, gunichar>;
-  
-  /*
-  template <>
-  struct ustring::SequenceToString<Glib::ustring::iterator, gunichar>;
-
-  template <>
-  struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar>;
-  */
-  
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
   std::string string_;
@@ -634,25 +592,25 @@ struct ustring::SequenceToString
 {};
 
 template <class In>
-struct ustring::SequenceToString<In, char> : public std::string
+struct ustring::SequenceToString<In,char> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <class In>
-struct ustring::SequenceToString<In, gunichar> : public std::string
+struct ustring::SequenceToString<In,gunichar> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::iterator, gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::iterator,gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::iterator pbegin, Glib::ustring::iterator pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::const_iterator,gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::const_iterator pbegin, Glib::ustring::const_iterator pend);
 };
